/**
 * Copyright 2014 Kakao Corp.
 *
 * Redistribution and modification in source or binary forms are not permitted without specific prior written permission. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kakao.kinsight.sample.android;

import java.util.Locale;

import com.kakao.kinsight.sdk.android.KinsightSession;

import android.app.ActionBar;
import android.app.FragmentTransaction;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentPagerAdapter;
import android.support.v4.view.ViewPager;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends FragmentActivity implements
		ActionBar.TabListener {

	/**
	 * The {@link android.support.v4.view.PagerAdapter} that will provide
	 * fragments for each of the sections. We use a
	 * {@link android.support.v4.app.FragmentPagerAdapter} derivative, which
	 * will keep every loaded fragment in memory. If this becomes too memory
	 * intensive, it may be best to switch to a
	 * {@link android.support.v4.app.FragmentStatePagerAdapter}.
	 */
	SectionsPagerAdapter mSectionsPagerAdapter;

	/**
	 * The {@link ViewPager} that will host the section contents.
	 */
	ViewPager mViewPager;
	
	public static KinsightSession kinsightSession;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		// 분석을 위한 세션 관리 객체 생성
		MainActivity.kinsightSession = new KinsightSession(getApplicationContext());

		// 세션 열기
		MainActivity.kinsightSession.open();
		// 화면(screen) 등록
		MainActivity.kinsightSession.tagScreen("MainActivity");

		// Set up the action bar.
		final ActionBar actionBar = getActionBar();
		actionBar.setNavigationMode(ActionBar.NAVIGATION_MODE_TABS);

		// Create the adapter that will return a fragment for each of the three
		// primary sections of the app.
		mSectionsPagerAdapter = new SectionsPagerAdapter(
				getSupportFragmentManager());

		// Set up the ViewPager with the sections adapter.
		mViewPager = (ViewPager) findViewById(R.id.pager);
		mViewPager.setAdapter(mSectionsPagerAdapter);

		// When swiping between different sections, select the corresponding
		// tab. We can also use ActionBar.Tab#select() to do this if we have
		// a reference to the Tab.
		mViewPager
				.setOnPageChangeListener(new ViewPager.SimpleOnPageChangeListener() {
					@Override
					public void onPageSelected(int position) {
						actionBar.setSelectedNavigationItem(position);
					}
				});

		// For each of the sections in the app, add a tab to the action bar.
		for (int i = 0; i < mSectionsPagerAdapter.getCount(); i++) {
			// Create a tab with text corresponding to the page title defined by
			// the adapter. Also specify this Activity object, which implements
			// the TabListener interface, as the callback (listener) for when
			// this tab is selected.
			actionBar.addTab(actionBar.newTab()
					.setText(mSectionsPagerAdapter.getPageTitle(i))
					.setTabListener(this));
		}
	}
	
	@Override
	public void onPause() {
		// 세션 닫기
		MainActivity.kinsightSession.close();
		
		super.onPause();
	}
	
	@Override
	public void onResume() {
		super.onResume();
		
		// 세션 열기
		MainActivity.kinsightSession.open();
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	@Override
	public void onTabSelected(ActionBar.Tab tab,
			FragmentTransaction fragmentTransaction) {
		// When the given tab is selected, switch to the corresponding page in
		// the ViewPager.
		mViewPager.setCurrentItem(tab.getPosition());
	}

	@Override
	public void onTabUnselected(ActionBar.Tab tab,
			FragmentTransaction fragmentTransaction) {
	}

	@Override
	public void onTabReselected(ActionBar.Tab tab,
			FragmentTransaction fragmentTransaction) {
	}

	/**
	 * A {@link FragmentPagerAdapter} that returns a fragment corresponding to
	 * one of the sections/tabs/pages.
	 */
	public class SectionsPagerAdapter extends FragmentPagerAdapter {

		public SectionsPagerAdapter(FragmentManager fm) {
			super(fm);
		}

		@Override
		public Fragment getItem(int position) {
			// getItem is called to instantiate the fragment for the given page.
			// Return a DummySectionFragment (defined as a static inner class
			// below) with the page number as its lone argument.
			Fragment fragment = new DummySectionFragment();
			Bundle args = new Bundle();
			args.putInt(DummySectionFragment.ARG_SECTION_NUMBER, position + 1);
			fragment.setArguments(args);
			return fragment;
		}

		@Override
		public int getCount() {
			// Show 3 total pages.
			return 3;
		}

		@Override
		public CharSequence getPageTitle(int position) {
			Locale l = Locale.getDefault();
			switch (position) {
			case 0:
				return getString(R.string.title_section1).toUpperCase(l);
			case 1:
				return getString(R.string.title_section2).toUpperCase(l);
			case 2:
				return getString(R.string.title_section3).toUpperCase(l);
			}
			return null;
		}
	}

	/**
	 * A dummy fragment representing a section of the app, but that simply
	 * displays dummy text.
	 */
	public static class DummySectionFragment extends Fragment {
		/**
		 * The fragment argument representing the section number for this
		 * fragment.
		 */
		public static final String ARG_SECTION_NUMBER = "section_number";

		public DummySectionFragment() {
		}

		@Override
		public View onCreateView(LayoutInflater inflater, ViewGroup container,
				Bundle savedInstanceState) {
			View rootView = inflater.inflate(R.layout.fragment_main_dummy,
					container, false);
			TextView dummyTextView = (TextView) rootView
					.findViewById(R.id.section_label);
			int sectionNumber = getArguments().getInt(ARG_SECTION_NUMBER);
			dummyTextView.setText(Integer.toString(sectionNumber));
						
			Button button;
			switch(sectionNumber) {
			case 1:
				button = (Button) rootView.findViewById(R.id.button1);
				button.setText(getString(R.string.title_button1));
				button.setOnClickListener(new OnClickListener() {
					public void onClick(View v) {
						Toast.makeText(DummySectionFragment.this.getActivity(), getString(R.string.title_button1), Toast.LENGTH_SHORT).show();
						// 사용자 액션(event) 등록 
						MainActivity.kinsightSession.addEvent(String.format("%s pressed", getString(R.string.title_button1))); //$NON-NLS-$1
					}
				});
				break;
			case 2:
				button = (Button) rootView.findViewById(R.id.button1);
				button.setText(getString(R.string.title_button2));
				button.setOnClickListener(new OnClickListener() {
					public void onClick(View v) {
						Toast.makeText(DummySectionFragment.this.getActivity(), getString(R.string.title_button2), Toast.LENGTH_SHORT).show();
						// 사용자 액션(event) 등록 
						MainActivity.kinsightSession.addEvent(String.format("%s pressed", getString(R.string.title_button2))); //$NON-NLS-$1

					}
				});
				break;
			case 3:
				button = (Button) rootView.findViewById(R.id.button1);
				button.setText(getString(R.string.title_button3));
				button.setOnClickListener(new OnClickListener() {
					public void onClick(View v) {
						Toast.makeText(DummySectionFragment.this.getActivity(), getString(R.string.title_button3), Toast.LENGTH_SHORT).show();
						// 사용자 액션(event) 등록 
						MainActivity.kinsightSession.addEvent(String.format("%s pressed", getString(R.string.title_button3))); //$NON-NLS-$1

					}
				});
				break;
			}
			
			return rootView;
		}
		
		@Override
		public void onResume() {
			super.onResume();

			// 세션 열기
			MainActivity.kinsightSession.open();
			// 화면(screen) 등록
			MainActivity.kinsightSession.tagScreen(String.format("tab%s", getArguments().getInt(ARG_SECTION_NUMBER)));
		}

	}

}
